%find_best created 12/06/2002

%find_best gives the best architecture and the path to follow for a given demand scenario and a targeted capacity

% For each architecture, it looks at the paths that will start above a certain minimum capacity and stop with a capacity over the targeted capacity.
% Those capacities are defined when D is created (with GenD)

%The outputs are:
%best_path: matrix containing the path providing the minimum average cost
%best_arch: corresponding initial architectures
%best_cost: vector containing the average costs of each paths
%best_NPV: vector of NPV for each scenarios in the binomial tree for the best case
%best_fixed: vector with Pareto optimal architecture, capacity of this architecture and cost
function [best_arch,best_path,best_cost,best_NPV,best_fixed]=find_best(Capm,D,Demand,P,LCC,IDC,OSC,deltac,x_all,c,r,p,dr)
close all
%Those two lines may need to be added in the main window:
%addpath('C:\Research\LEO Constellations\CD-ROM\LEOcode_4202\LEOcode\New Tradespace\Cost Module')
%addpath('C:\Research\LEO Constellations\CD-ROM\LEOcode_4202\LEOcode\New Tradespace\Path Design')

cmin=D.capmin;
cmax=D.target;
nx=length(x_all);
i=1;
best_path=[];
best_cost=[1/eps]; %To initialize, we set a very large number
best_arch=[];
best_NPV=[];

%bfix is the best fixed architecture (on the Pareto front with a capacity higher than D.target)
bfix=find_bestfixed(D,x_all,Capm,LCC);
best_fixed=bfix;

counter=0;
hfig=waitbar(0.01,'Analyzing the architectures... Please wait','Position',[360 514 280 60]);

while i<=nx
    % 1/ We check if the architecture has a capacity smaller than the minimum capacity or a capacity higher than the
    % Pareto optimal one (in both cases, it is not an interesting initial architecture)
    if Capm(i)<=cmin|Capm(i)>bfix(2,1)
    % We don't consider the architecture and don't do anything
    else
        %2/ We check if the architecture can attain a capacity higher than cmax
        Tanc=ancestors(i,x_all,Capm);
        [nanc,manc]=size(Tanc); 
        if Tanc(1,manc)<cmax %Tanc(1,manc) is the highest capacity in the family
        % We don't do anything
        else
            %3/ We generate all the paths possible from this architecture
            S=fullpath(i,x_all,Capm);
            %4/ For each path in S, we check if it attains cmax and if it is, calculates the cost
            [ns,ms]=size(S);
            for k=1:ns
                path=S(k,:);
                % We need to remove the zeros in path
                stop=0;
                while stop~=1
                    if path(1,length(path))==0
                        path(:,length(path))=[];
                    else
                        stop=1;
                    end
                end
                % We look at the maximm capacity of the path
                if Capm(path(1,length(path)))<cmax
                   % We don't do anything
                else %We calculate the average cost of this feasible path
                   [Sc,cost,Pr,NPV,flag]=archsc(path,Capm,D,Demand,P,IDC,OSC,deltac,0,0,x_all,c,r,p,dr);
                   % We set XM and XV to zero in this model               
                    % We compare this cost to the one of best_cost (we look at the first element of best_cost)
                    if cost<best_cost
                     best_cost=cost;
                     best_path=[path];
                     best_arch=[i];
                     best_NPV=NPV;
                    elseif cost==best_cost
                      [nbp,mbp]=size(best_path);
                      best_arch=[best_arch; i];
                      l=length(path);
                        if l==mbp
                          best_path=[best_path; path];
                        elseif l<mbp
                         best_path=[best_path; [path zeros(1,mbp-l)]];
                        else
                         best_path=[best_path zeros(nbp,l-mbp)];
                         best_path=[best_path; path];
                        end
                    else
                    end
                end
            end
        end
    end
    i=i+1;
    counter=counter+1;
    waitbar(counter/nx,hfig);
end

close(hfig);
%We need to add the following outputs:
%Calculate extreme costs for the best architectures.

%subplot(2,1,1)
% We plot the Trade space (in green)
hold on;
loglog(Capm/1000,LCC/(1000*1000),'g+');
line([D.initial/1000 D.initial/1000],[0.1 100],'LineWidth',1);
line([D.target/1000 D.target/1000],[0.1 100],'LineWidth',1);
xlabel('Capacity [thousands of users]')
ylabel('System Lifecycle Cost [B$]')
title('Trade Space')

% We plot the best paths identified (in blue)
[nbp,mbp]=size(best_path);
for i=1:nbp
    plotpath(best_path(i,:),Capm,LCC);
end

% We plot the best architecture (black square)
plot(bfix(2,1)/1000,bfix(3,1)/(1000*1000),'ks');

% We plot our average cost in the Trade Space (red square)

plot(bfix(2,1)/1000,best_cost/(1000*1000),'rs');

% We plot the distribution of our final costs for the best architecture
%subplot(2,1,2)
%[dNPV,dP]=NPV_distribution(best_NPV,P)
%plot(dNPV,dP);

%We calculate the percentage of money saved:
perc_saved=(bfix(3,1)-best_cost)/bfix(3,1);
fprintf('The percentage of money saved is %d .\n',perc_saved);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Sub-function

%plotpath
%Given a path "path" plotpath represents it in the Trade Space
function h=plotpath(path,Capm,LCC)
stop=0;
while stop~=1
   if path(1,length(path))==0
      path(:,length(path))=[];
   else
      stop=1;
   end
end

n=length(path);
if n==1 %We don't do anything
else
    for i=2:n
        line([Capm(path(i-1))/1000 Capm(path(i))/1000],[LCC(path(i-1))/(1000*1000) LCC(path(i))/(1000*1000)]);
    end
end
% We now represent the architectures one by one (blue circle)
for i=1:n
    plot(Capm(path(1,i))/1000,LCC(path(1,i))/(1000*1000),'bo');
end

%find_bestfixed
%This function finds the best fixed architecture (Pareto optimal) for a given projected demand
%The outuput vector is S=[best architecture i; Capm(i); LCC(i)]

function S=find_bestfixed(D,x_all,Capm,LCC)

nx=length(x_all);
cmax=D.target;
S=[0;-1;1/eps];
for i=1:nx
    if Capm(i)>=cmax
        if LCC(i)<S(3,1);
            S=[i;Capm(i);LCC(i)];
        else
        end
    else
    end
end

%NPV_distribution

%Given scenarios for the final costs (gathered in NPV) and their probabilities (in P)
%the function gives the final possible values for the costs (dNPV) and their probabilities (dP)

function [dNPV,dP]=NPV_ditribution(NPV,P)
%1/ First, we need to eliminate the identical values for cost in NPV
X=NPV;
stop=0; k=1;%stop is a flag that tels us when to stop
while stop~=1
    l=length(X);
    a=X(k);
    if k==l
        stop=1;
    else
        for i=0:l-k-1
            if a==X(l-i)
                X(l-i)=[];
            else
            end
        end
        l=length(X);
        if k==l;
        stop=1;
        else
            k=k+1;
        end
    end
end

%2/ We reorder the entries of X in increasing order
A=X;
X=[];
stop=0;
while stop~=1
    if length(A)==0;
        stop=1;
    else
        [c,i]=min(A);
        X=[X; c];
        A(i)=[];
    end
end

%3/ We create a vector dP with the probabilties of each final costs
l=length(X);
np=length(NPV);
dP=[];
for i=1:l
    totP=0;
    for k=1:np
        if NPV(k)==X(i)
            totP=totP+P(k);
        else
        end
    end
    dP=[dP; totP];
end

dNPV=X;
            
    