% function costw.m
%
% finding the total cost of the project
%
% by Darren Zhang (darrenz@mit.edu)
% Modified by Mathieu Chaize (chaize@mit.edu)

% This module provides the maintenance costs (maint_cost) and initial deployment cost (ID_cost)
% of a constellation.
% Extra outputs:
% Lastsat_cost: cost of the last satellite built

% Steps 1 and 2: find Space Mission Characteristics.
% Some of these have been calculated or set up in previous modules.
% For those that have not been set up, I'll temporarily set them to
% arbitrary values here.
function [ID_cost,maint_cost,Lastsat_cost,TFUHC] = cost(N,NP,alti,AntW,CEW,SCBDW,SWW,BLP,FSKLOC,GSKLOC,spaceLife,IDTime,NGS,personnel,AKM,AKMDW,totImpulse,DR,minLaunchCost)
N;						% # of sats in the constellation
alti;					% orbit altitude, in km
PLType = 'Comm';	% payload type is always Comm
AntW;					% antenna weight, in kg
CEW;					% comm electonics weight, in kg
SCBDW;				% spacecraft bus dry weight, in kg
SWW;					% satellite wet weight, in kg
BLP;					% beginning of life power, in W
FSKLOC;				% flight software lines of code, in thousand lines
GSKLOC;				% ground software lines of code, in thousand lines
spaceLife;			% space segment design life, in years
IDTime;				% initial deployment time, in years
NGS;					% number of ground stations
personnel;			% number of operations and support personnel
spareSC = NP;		% number of spare spacecraft = number of planes in the constellation
AKM;					% type of apogee kick motor.  0 for no AKM, 1 for spin-stablized and 2 for 3-axis-stablized
AKMDW;				% AKM dry weight
totImpulse;			% total impulse of AKM
minLaunchCost;		% from LV.m
DR;					% discount rate in percentage

% Step 3: find RDT&E Hardware Cost in FY2002$K
% Assuming Nominal new design with some heritage
% Assuming commercial program, the cost factored by 0.8
% All money values converted from 1992 to 2002 USD by multiplying 1.369

Cant		= 1015*AntW^0.59;		% cost of antenna
CcommEle	= 917*CEW^0.7;			% cost comm electronics
CscBus	= 16253 + 110*SCBDW;	% cost of spacecraft bus
if AKM == 1							% cost of apogee kick motor, 1 for spin-stabllized   									
   Cakm = 490 + 0.0518*totImpulse;	
elseif AKM == 2					% 2 for 3-axis stablized
   Cakm = 0.0156*totImpulse;
else
   Cakm = 0;
end;
RDTEHC = (Cant + CcommEle + CscBus + Cakm)*0.8*1.369; % RDT&E Hardware Cost

% Step 4: find TFU Hardware Cost in FY2002$K
% Assuming commercial program
% All money values converted from 1992 to 2002 USD by multiplying 1.369

Cant		= 20 + 230*AntW^0.59;
CcommEle	= 179*CEW;
CscBus	= 185*SCBDW^0.77;
if AKM == 1							
   Cakm = 58*AKMDW^0.72;	
elseif AKM == 2
   Cakm = 0.0052*totImpulse;
else
   Cakm = 0;
end;
TFUHC = (Cant + CcommEle + CscBus + Cakm)*0.8*1.369; % TFU Hardware Cost

% Step 5: find hardware cost of every unit in FY2002$K
% first, find learning curve slope LCS in percentage
% Assume that for each plane there is a spare satellite.
totN = N + spareSC;		% total number of sats
if totN < 10
   LCS = 95;
elseif 10 <= totN & totN <=50
   LCS = 90;
else
   LCS = 85;
end;
% second, find the hardware cost of each unit
B = 1 - log(100/LCS)/log(2);
previousCost = 0;
for i = 1:totN;
   LCF = i^B;	% learning curve factor
   UHC(i) = TFUHC*LCF - previousCost;
   previousCost = TFUHC*LCF;
end;
Lastsat_cost=UHC(totN);

% Step 5.5: hardening adds 2~5% to the total cost of the satellites
% Table 8-6, SMAD
% When the orbit altitude reaches 650km, hardening is needed to protect the s/c 
% from Van Allen belts
if alti >= 650
    UHC = UHC*1.05;
else
    ;
end;

% Step 6: find Aerospace Ground Equipment Cost for RDT&E in FY2002$K
AGEC = 0.11*(RDTEHC + TFUHC);

% Step 7: find total Program Level Cost for RDT&E, TFU, and all the rest of the units in FY2002$K
RDTEPLC = 0.36*RDTEHC;
UPLC = 0.33.*UHC;
totPLC  = RDTEPLC + sum(UPLC);

% Step 8: find Launch Operations and Orbit Support Cost for all units in FY2002$K
if AKM == 0
   LOOSC = 2.51*SWW;
else
   LOOSC = 64 + 1.44*SWW;
end;
totLOOSC = LOOSC*totN*0.8*1.369;

% Step 9: find Flight Software Cost in FY2002$K
FSC = FSKLOC*375*0.8*1.369;

% Step 10: find Launch Vehicle Cost in FY2002$K
LVC = minLaunchCost;

% Step 11: find Ground Software Cost in FY2002$K
% Assuming using UNIX - C
GSC = GSKLOC*190*1.67*0.8*1.369;

% Step 12: find total Ground Segment Development Cost in FY2002$K
GSDC = (18 + 81 + 100 + 15 + 18 + 30 + 15 + 24)/100*GSC;
% command center cost, assuming two CC built, cost based on GlobalStar, ARIES, ORBCOMM, and Starnet
CCC = 7500*2*1.369;
totGSDC = NGS*GSDC + CCC;

% Step 13: find Initial Deployment Cost in FY2002$K
IDC = RDTEHC + sum(UHC) + AGEC + totPLC + totLOOSC + FSC + totGSDC + LVC;
ID_cost=IDC;

% Step 14: find IDC distribution over Initial Deployment Time (we remove this part)
% Assume 60% of expenditure at schedule midpoint
%previousCostFraction = 0;
%for i = 1:IDTime
%   Atmp = 0.32;
%   Btmp = 0.68;
%   Stmp = i/IDTime;
%   costFraction = Atmp*(10 + Stmp*((15 - 4*Stmp)*Stmp - 20))*Stmp^2 + Btmp*(10 + Stmp*(6*Stmp - 15))*Stmp^3 + (1 - (Atmp + Btmp))*(5 - 4*Stmp)*Stmp^4;
%   CostPerYear(i) = (costFraction - previousCostFraction)*IDC;
%   previousCostFraction = costFraction;
%end;

% Step 15: find Operation and Support Cost per year during Space Segment Life Time in FY2002$K
% Assume contractor labor
maintCost = (18 + 81 + 100)/100*GSC*0.1;
laborCost = 140*personnel;
OSCPerYear = maintCost + laborCost;
maint_cost=OSCPerYear;

% Step 16: find OSC distribution over Space Segment Life Time (we remove this part)
%for i = (IDTime + 1):(IDTime + spaceLife)
%   CostPerYear(i) = OSCPerYear;
%end;

% Step 17: discount Cost Per Year to Present Cost
% Discount rate is chosen by the user
%for i = 1:(IDTime + spaceLife)
%   PCPerYear(i) = CostPerYear(i)/(1+DR/100)^i;
%end;
%PC = sum(PCPerYear);

% Step 18: add 10% Fee
%totalPresentCost = PC*(1 + 0.1);

% Step 19: find Cost Uncertainty Std. Dev.
% Assume a Technology Readiness Level b/w 4 and 5, which
% gives a Std. Dev. about MLE of 15%

%STSDscBus = CscBus*0.15;		% STSD - System Technology Std. Dev.
%STSDant   = Cant*0.15;
%STSDcommEle = CcommEle*0.15;

%CESDscBus = 6655;					% Cost Estimate Std. Dev.
%CESDant   = 476;
%CESDcommEle = 8235;

%CSDscBus = sqrt(STSDscBus^2 + CESDscBus^2);	% Combined Std. Dev.
%CSDant   = sqrt(STSDant^2 + CESDant^2);
%CSDcommEle = sqrt(STSDcommEle^2 + CESDcommEle^2);

%CSDSum = CSDscBus + CSDant + CSDcommEle;
%CSDRSS = sqrt(CSDscBus^2 + CSDant^2 + CSDcommEle^2);

%costSDAvg = (CSDSum + CSDRSS)/2;

%totalPresentCost = totalPresentCost/1000;		% in FY2002$M
%costSDAvg = costSDAvg/1000;                     % in FY2002$M



   
   

