function [N_Customers]=customer(N_Planes, n_SAT_per_Plane, Inclination, ...
                                Altitude, C_SAT_Effective, Market_Demand_Size, Elevation_Min)

% Module for calculating the number of customers from the design variables and assumptions.
% Tatsuki Kashitani, 3/2/2002

% INPUT:
%   N_Planes            Number of orbital planes            #
%   n_SAT_per_Plane     Number of satellites per plane      #
%   Inclination         Inclination angle of planes         radian
%   Altitude            Altitude of orbit                   m
%   C_SAT_Effective     Satellite's capacity at effective path length
%                                                           users/satellite
%   Market_Demand_Size  Size of the market demand           #
%   Elevation_Min       Minimum elevation angle required    radian

% OUTPUT
% N_Customers           Number of customers constellation gets  #

% Constants
R_Earth = 6378137; % m

% Load market distribution map
load('Market_Distribution');

% Find number of satellites
N_Satellites = N_Planes * n_SAT_per_Plane;

% Find angle from nader to the edge of foot print using the sine formula.
Angle_FOV = asin ( R_Earth / (Altitude + R_Earth ) * sin( Elevation_Min + pi/2 ));
%disp(sprintf('Angle from satellite''s nadir to the edege of FOV is %2.1f degrees.', Angle_FOV*(180/pi)));

% Find the angle from the point directly below the satellite to the edge of FOV measured
% about the center of the Earth.
Angle_Footprint = pi - ( Elevation_Min + pi/2 ) - Angle_FOV;
%disp(sprintf('Radius of satellite''s footprint measured in latitude is %2.1 degrees.', Angle_Footprint*(180/pi)));

% Assume symetry in longitudinal direction
% Assume symetry about the equator
% Assume constant coverage under nadir (latitude = 0 ~ inclination)
% Assume linearly decreasing coverage from nadir to FOV edge (latitude = inclination ~ inclination + Angle_Footprint)
% Initialize latitudinal capacity density grid
% 15 deg by 15 deg grid
% i = 1  <==> latitude =  0 ~ 15
% i = 2  <==> latitude = 15 ~ 30
% i = 3  <==> latitude = 30 ~ 45
% i = 4  <==> latitude = 45 ~ 60
% i = 5  <==> latitude = 60 ~ 75
% i = 6  <==> latitude = 75 ~ 90
Latitudinal_Capacity_Density = zeros(6, 1);

% Calculate the coverage edge slope
a = -1/Angle_Footprint;
b = 1 + Inclination / Angle_Footprint;

% Calculate the values on the edge slope at grid boundaries
% n = 1  <==> latitude =  0
% n = 2  <==> latitude = 15
% n = 3  <==> latitude = 30
% n = 4  <==> latitude = 45
% n = 5  <==> latitude = 60
% n = 6  <==> latitude = 75
% n = 7  <==> latitude = 90
for n = 1:7
    s(n) = a * (n-1)*(pi/12) + b;
end

% Find coverage for grids
for i = 1:6
    if s(i+1) >= 1
        %disp('Flat')
        Latitudinal_Capacity_Density(i) = 1;
        
    elseif ( s(i) >= 1 ) & ( s(i+1) >= 0 )
        %disp('Flat + Slope')
        Latitudinal_Capacity_Density(i) = Inclination / (pi/12) - (i - 1) + ...
            0.5 * (1 + s(i+1) ) * ( i - Inclination / (pi/12) );
        
    elseif ( s(i) >= 1 ) & ( s(i+1) < 0 )
        %disp('Flat + Traiangle')
        Latitudinal_Capacity_Density(i) = Inclination / (pi/12) - (i - 1) + ...
            0.5 * Angle_Footprint / (pi/12);
        
    elseif ( s(i) > 0 ) & ( s(i+1) >= 0 )
        %disp('Trapezoid')
        Latitudinal_Capacity_Density(i) = 0.5 * ( s(i) + s(i+1) );
        
    elseif ( s(i) > 0 ) & ( s(i+1) < 0 )
        %disp('Triangle')
        Latitudinal_Capacity_Density(i) =  0.5 * s(i) * ( ( Inclination + Angle_Footprint ) / (pi/12) - (i-1) );
    elseif ( s(i) <= 0 )
        %disp('Empty')
        Latitudinal_Capacity_Density(i) = 0;
    end
end

% Expand latitudinal capacity density to 10*24 map
System_Capacity_Distribution = zeros(10, 24);

% Northern hemisphere
for i = 1:6
    System_Capacity_Distribution(i,:) = Latitudinal_Capacity_Density(7-i) * ones(1,24);
end
% Southern hemisphere
for i = 7:10
    System_Capacity_Distribution(i,:) = Latitudinal_Capacity_Density(i-6) * ones(1,24);
end

% Normalize the capacity distibution
System_Capacity_Distribution = System_Capacity_Distribution / sum(sum(System_Capacity_Distribution));

% Multiply by the capacity to get capacity map
System_Capacity = N_Satellites * C_SAT_Effective * System_Capacity_Distribution;

% Mulityply the market distribution by total market size to get market map
Market_Demand = Market_Demand_Size * Market_Distribution;

% Take minimum of market demand and system capacity to get customers
Customer = min( Market_Demand, System_Capacity);

% Plot maps
%imagesc(Market_Demand); colorbar('horiz');title('Market Demand');figure
%imagesc(System_Capacity); colorbar('horiz');title('System Capacity');figure
%imagesc(Customer); colorbar('horiz');title('Customer')

% Find total number of customers
N_Customers = sum(sum(Customer));