% function stk.m
% a function that connects to STK
% and presents the final design in
% STK
% by Darren Zhang (darrenz@mit.edu)
% last modified on 1/28/02

function stk(delta,central,orbitR,incli,alti,NPmin,NSmin,LScounter,launchSite,launchVehicle,LVModelFileName,satPerVehicle,numberOfLaunch,LPModelFileName,LSla,LSlo,burnoutVelocity)
% --------------------Part I - Set up STK connection and creat a scenario--------------------
% initialize mexconnect
stkinit

% Open the Connect to STK
%
conid=stkOpen('localhost:5001');

dtr = pi/180;
rtd = 180/pi;
% first check to see if a scenario is open
scen_open = stkValidScen;

if scen_open == 1
   rtn = input('STK will close the open scenario - Type 1 to close the scenario, 2 to cancel this script - ');
   if rtn == 2
      stkclose(conid)
      return
   else
      stkUnload('/*')
   end
end

% create a new scenario
disp('Create a new scenario');
stkNewObj('/','Scenario','Constellation_Basic');

% set time period
disp('Set scenario time period');
stkSetTimePeriod('1 May 2000 00:00:00.0','2 May 2000 00:00:00.0','GREGUTC');
stkSetEpoch('1 May 2000 00:00:00.0','GREGUTC');
rtn = stkConnect(conid,'Animate','Scenario/Constellation_Basic','SetValues "1 May 2000 00:00:00.0" 60 0.1');
rtn = stkConnect(conid,'Animate','Scenario/Constellation_Basic','Reset');

% --------------------Part II - Calculate the constelltion parameters and create satellites one by one--------------------
% Part II is based on coverage.m
% All parameters of a satellite are set to "fit in" the constellation

% Polar constelltion co-rotating planes are separated by central angle + delta
% while counter-rotating planes are separated by 2*delta
delta_d 		= delta*rtd;
central_d	= central*rtd;

mu_earth		= 3.986e14;										% m^3/s^2
meanMotion	= (86400/2/pi)*sqrt(mu_earth/orbitR^3);% satellite angular velocity in rev./day

% Darren's polar constellation setup protocol (DaPoCSUP):
% The plane with a 0 degree RAAN is the plane 1 in the constellation.
% Viewed from the North Pole, the plane to the immediate east of plane 1
% is the counter-rotating plane.  Its number is Nmin, whatever that might
% be calculated in coverage.m.  The separation b/w plane 1 and plane Nmin
% is 2*delta. There is no phase angle difference b/w two counter-rotating
% planes. The plane to the immediate west of plane 1 is the co-rotating
% plane.  Its number is 2.  The separation b/w plane 1 and plane 2 is 
% (central + delta).  The phase angle difference b/w two co-rotating planes
% is pi/NSmin.
%
% Satellite 1 of plane 1 starts at the equatorial plane at time 0.  Satellite
% 2 of plane 1 starts at an argument of perigee (ArgPeri) of 2pi/NSmin, etc.
% Satellite 1 of plane 2 starts at a ArgPeri of pi/NSmin, while its RAAN is
% (central + delta).  Satellite 1 of plane 3 starts at ArgPeri of 2*pi/NSmin
% and RAAN of 2(central + delta), etc.


% stkSetPropClassical  Set propagator parameters, classical coordinates
%
% USAGE    stkSetPropClassical('objPath', 'propagator', 'coordSystem', ...
%              tStart, tStop, dt, orbitEpoch, semimajorAxis, eccentricity,...
%              inclination, argOfPerigree, RAAN, meanAnomaly, coordEpoch)
%
%	objPath - Valid path, may be obtained from stkObjNames.
%	propagator - 'TwoBody', 'J2Perturbation', 'J4Perturbation', 'HPOP' or 'PODS'
%                  This parameter is case sensitive!
%	coordSystem - string name of coordinate system, valid choices are:
%	              'Fixed', 'J2000', 'MeanOfDate', 'MeanOfEpoch', 
%	              'TrueOfDate', 'TrueOfEpoch', 'B1950',
%	              'TEMEOfDate', 'TEMEOfEpoch', 'AlignmentAtEpoch'.
%                  This parameter is case sensitive!
%	tStart, tStop - times in epoch seconds.
%	dt - time step in seconds.
%	orbitEpoch - reference time of orbit data, in scenario epoch seconds
%	coordEpoch - coordinate system epoch, required by all '...OfEpoch'
%	             coordinate systems.
%
% For information on the following parameters, please consult the STK Users Manual:
%
%	semimajorAxis - units in meters
%	eccentricity - unitless
%	inclination - units in radians
%	argOfPerigee - units in radians
%	RAAN - units in radians
%	meanAnomaly - units in radians
% Among all these inputs, only objPath, argOfPerigee, RAAN, meanAnomaly,
% vary from satellite to satellite.  The other inputs are constants
% in the same polar constellation.
for Pcount = 1:NPmin
   for Scount = 1:NSmin
      % create a new satellite
      fprintf('Creating Satellite %2.0f\n in Plane %2.0f\n',Scount,Pcount);
      
      satNumb = Scount + (Pcount - 1)*NSmin;
      satName = strcat('Sat',num2str(satNumb));
      stkNewObj('*/','Satellite',satName);
      
      objPath 			= strcat('*/Satellite/',satName);
      argOfPerigee 	= (Scount - 1)*(2*pi/NSmin);
      RAAN				= (Pcount - 1)*(central + delta);
      meanAnomaly		= pi - argOfPerigee;
      orbitEpoch		= '01100.0000000';
      incli				= 90.0*dtr;
      semiMajorAxis	= orbitR*1000;								% in meters
      
      % set up the propagator for the satellite
      %stkSetPropClasical('objPath', 'propagator', 'coordSystem',tStart, tStop, dt, orbitEpoch, semimajorAxis, eccentricity,inclination, argOfPerigee, RAAN, meanAnomaly, coordEpoch)
		stkSetPropClassical(objPath,'J4Perturbation','J2000',0.0,86400.0,60.0,0,semiMajorAxis,0.0,incli,argOfPerigee,RAAN,0.0);
      
      % set up the attitude for the satellite
      % USAGE  stkSetAttBasic('satPath', 'attType', offset)
		%
		%	satPath - string name of satellite
		%	offset - either an alignOffset or constraintOffset, depending on type (radians)
		%	attType - attitude type string.  Valid choices are:
		%	        NADIRECIVEL
		%	        NADIRECFVEL
		%	        NADIRSUN
		%	        NADIRORBIT
		%	        ECIVELNADIR
		%	        ECFVELNADIR
		%	        SUNNADIR
		%	        SUNECLIPTIC
		%	        SUNECIZ
		%	        SUNOCCULT 
      stkSetAttBasic(objPath,'NADIRECFVEL',0.0);
   end;
end;

% create the capable launch vehicles and sites in STK
for counter = 1:LScounter
   % create launch sites
   repeated = 0;
   for counter2 = 1:(counter-1)		% check if this launch site has been created
      if strcmp(char(launchSite{counter}),char(launchSite{counter2}))
         repeated = 1;
      else
      end;
   end;
   if repeated == 0				% if repeated launch site, don't create duplicate luanch site.
      stkNewObj('*/','Facility',char(launchSite{counter}));				% create Launch Site
      objPath = strcat('*/Facility/',char(launchSite{counter}));		% path of Launch Site
      llaPos  = [LSla(counter);LSlo(counter)];								% latitude and longitude of LS
      stkSetFacPosLLA(objPath,llaPos);											% set LS location
      command = strcat('VO Scenario/Constellation_Basic/Facility/',char(launchSite{counter}),' ScaleLog 2.0');
      stkExec(conid,command);
      stkNewObj('*/','Facility',strcat('launch_pad_',char(launchSite{counter})));		% create launch pad
      objPath = strcat('*/Facility/',strcat('launch_pad_',char(launchSite{counter})));	% path of launch pad
      llaPos  = [LSla(counter) + 0.5*dtr;LSlo(counter) + 0.5*dtr];							% latitude and longitude of LP
      stkSetFacPosLLA(objPath,llaPos);																	% set LP location
      command = strcat('VO Scenario/Constellation_Basic/Facility/',strcat('launch_pad_',char(launchSite{counter})),' ScaleLog 2.5');     
      stkExec(conid,command);
      command = strcat('VO Scenario/Constellation_Basic/Facility/',strcat('launch_pad_',char(launchSite{counter})),' Model ON "C:/Program Files/AGI/stk/4.2.1/STKData/VO/Models/Ground/Facilities/',char(LPModelFileName{counter}),'"');
      stkExec(conid,command);
   else
   end;
   
   % create launch vehicles
   stkNewObj('*/','LaunchVehicle',char(launchVehicle{counter}));	% create LV
   % set parameters
   burnoutLA = LSla(counter)*rtd + 10;										% for now arbitrarily set burnout latitude to be 10 degree more than launch site latitude
   burnoutLO = LSlo(counter)*rtd - 10;										% and burnout longitude to be 10 degree less than launch site longitude
   strtmp												= num2str(LSla(counter)*rtd+0.1);
   spcLSla(1)											= ' ';
   spcLSla(2:(length(strtmp)+1)) 				= strtmp;
   strtmp												= num2str(LSlo(counter)*rtd+0.1);
   spcLSlo(1)											= ' ';
   spcLSlo(2:(length(strtmp)+1)) 				= strtmp;
   spc0(1)												= ' ';
   spc0(2)												= '0';
   strtmp												= num2str(burnoutVelocity(counter));
   spcburnoutVelocity(1) 							= ' ';
   spcburnoutVelocity(2:(length(strtmp)+1)) 	= strtmp;
   strtmp												= num2str(burnoutLA);
   spcburnoutLA(1) 									= ' ';
   spcburnoutLA(2:(length(strtmp)+1)) 			= strtmp;
   strtmp												= num2str(burnoutLO);
   spcburnoutLO(1) 									= ' ';
   spcburnoutLO(2:(length(strtmp)+1)) 			= strtmp;
   strtmp												= num2str(alti*1000);
   spcalti(1) 											= ' ';
   spcalti(2:(length(strtmp)+1)) 				= strtmp;
   % set LV state
   command = strcat('SetState Scenario/Constellation_Basic/LaunchVehicle/',char(launchVehicle{counter}),' SimpleAscent "1 May 2000 00:00:00.00" 1.0 Geodetic',spcLSla,spcLSlo,spc0,spcburnoutVelocity,spcburnoutLA,spcburnoutLO,spcalti); 
   stkExec(conid,command);
   % set LV model
   command = strcat('VO Scenario/Constellation_Basic/LaunchVehicle/',char(launchVehicle{counter}),' Model ON "C:/Program Files/AGI/stk/4.2.1/STKData/VO/Models/LaunchVeh/',char(LVModelFileName{counter}),'"');
   stkExec(conid,command);
   % set LV scale
   command = strcat('VO Scenario/Constellation_Basic/LaunchVehicle/',char(launchVehicle{counter}),' ScaleLog 2.5');
   stkExec(conid,command);
end;

% Refresh the STK VO window
stkExec(conid,'Animate Scenario/Constellation_Basic Reset');
